Copy a shipped example init file into your working directory
Source:R/usability.R
spesim_use_example.RdConvenience helper for workshops: copy an example init file from the package into the current directory (or a specified location) so students can edit it.